pub struct NdTensorBinding {
pub tensor_id: String,
pub representation_id: RepresentationId,
pub container: String,
pub dtype: NdTensorDType,
pub source_ids: Vec<SourceId>,
pub shape: Vec<usize>,
pub row_count: usize,
pub tensor_fingerprint: String,
}Expand description
Binding of one stored tensor to a materialized data handle.
Fields
tensor_id: Stringrepresentation_id: RepresentationIdcontainer: Stringdtype: NdTensorDTypesource_ids: Vec<SourceId>shape: Vec<usize>row_count: usizetensor_fingerprint: StringTrait Implementations
Sourceimpl Clone for NdTensorBinding
impl Clone for NdTensorBinding
Sourcefn clone(&self) -> NdTensorBinding
fn clone(&self) -> NdTensorBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NdTensorBinding
impl Debug for NdTensorBinding
Sourceimpl<'de> Deserialize<'de> for NdTensorBinding
impl<'de> Deserialize<'de> for NdTensorBinding
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<NdTensorBinding, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<NdTensorBinding, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NdTensorBinding
Sourceimpl PartialEq for NdTensorBinding
impl PartialEq for NdTensorBinding
Sourcefn eq(&self, other: &NdTensorBinding) -> bool
fn eq(&self, other: &NdTensorBinding) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NdTensorBinding
impl Serialize for NdTensorBinding
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for NdTensorBinding